==> yast2-4.6.2.tar.bz2: yast2-4.6.2/README.md <==
YaST - The Basic Libraries
==========================

[![Workflow Status](https://github.com/yast/yast-yast2/workflows/CI/badge.svg?branch=master)](
https://github.com/yast/yast-yast2/actions?query=branch%3Amaster)
[![Jenkins Status](https://ci.opensuse.org/buildStatus/icon?job=yast-yast-yast2-master)](
https://ci.opensuse.org/view/Yast/job/yast-yast-yast2-master/)
[![Coverage Status](https://img.shields.io/coveralls/yast/yast-yast2.svg)](https://coveralls.io/r/yast/yast-yast2?branch=master)
[![Code Climate](https://codeclimate.com/github/yast/yast-yast2/badges/gpa.svg)](https://codeclimate.com/github/yast/yast-yast2)

This repository contains basic set of shared libraries and so-called SCR agents
used for reading and writing configuration files and some even for executing
commands on the system.


Provided Functionality
======================

See [the generated yardoc documentation](http://www.rubydoc.info/github/yast/yast-yast2) at rubydoc.info.

It contains some general overview of yast2 parts:

* [Desktop Files](doc/desktop_file.md)
* [Installation Hooks](library/general/doc/Hooks.md)


Getting the Sources
===================

To get the source code, clone the GitHub repository:

    $ git clone https://github.com/yast/yast-yast2.git

If you want to contribute into the project you can
[fork](https://help.github.com/articles/fork-a-repo/) the repository and clone your fork.


Development
===========

This module is developed as part of YaST. See the
[development documentation](http://yastgithubio.readthedocs.org/en/latest/development/).


Contact
=======

If you have any question, feel free to ask at the [development mailing
list](http://lists.opensuse.org/yast-devel/) or at the
[#yast](https://web.libera.chat/#yast) IRC channel on libera.chat.

==> yast2-5.0.13.tar.bz2: yast2-5.0.13/README.md <==
YaST - The Basic Libraries
==========================

[![Workflow Status](https://github.com/yast/yast-yast2/workflows/CI/badge.svg?branch=master)](
https://github.com/yast/yast-yast2/actions?query=branch%3Amaster)
[![OBS](https://github.com/yast/yast-yast2/actions/workflows/submit.yml/badge.svg)](https://github.com/yast/yast-yast2/actions/workflows/submit.yml)
[![Coverage Status](https://img.shields.io/coveralls/yast/yast-yast2.svg)](https://coveralls.io/r/yast/yast-yast2?branch=master)
[![Code Climate](https://codeclimate.com/github/yast/yast-yast2/badges/gpa.svg)](https://codeclimate.com/github/yast/yast-yast2)

This repository contains basic set of shared libraries and so-called SCR agents
used for reading and writing configuration files and some even for executing
commands on the system.


Provided Functionality
======================

See [the generated yardoc documentation](http://www.rubydoc.info/github/yast/yast-yast2) at rubydoc.info.

It contains some general overview of yast2 parts:

* [Desktop Files](doc/desktop_file.md)
* [Installation Hooks](library/general/doc/Hooks.md)


Getting the Sources
===================

To get the source code, clone the GitHub repository:

    $ git clone https://github.com/yast/yast-yast2.git

If you want to contribute into the project you can
[fork](https://help.github.com/articles/fork-a-repo/) the repository and clone your fork.


Development
===========

This module is developed as part of YaST. See the
[development documentation](http://yastgithubio.readthedocs.org/en/latest/development/).


Contact
=======

If you have any question, feel free to ask at the [development mailing
list](http://lists.opensuse.org/yast-devel/) or at the
[#yast](https://web.libera.chat/#yast) IRC channel on libera.chat.
